@@ -123,31 +123,23 @@ class DeviceOption(metaclass=ABCMeta):
     def to_local(self):
         self.device.to_local()
 
-class ListDeviceOption(DeviceOption):
-    """Device option, that accepts only values, present
-    in a special list
-    TODO: remove completely in favor of ListControl"""
+class ListControl(DeviceOption):
+    """
+    List control has only a certain set of values, which also
+    can have a separate human-readable interpretation.
+    """
 
     def __init__(self, name, values_list, get_func=None, set_func=None, enabled=None):
         super().__init__(name, get_func, set_func, enabled)
+        # Convert dict to bidict to have a faster backward conversion
+        if isinstance(values_list, dict) and not isinstance(values_list, bidict):
+            values_list = bidict(values_list)
         self._values_list = values_list
 
     def values_list(self):
         """return the list of the valid values"""
         return self._values_list
 
-    def get_value(self):
-        return self._fget()
-
-    def set_value(self, value):
-        self._fset(value)
-
-class ListControl(ListDeviceOption):
-    """
-    List control has only a certain set of values, which also
-    have a human-readable interpretation.
-    """
-
     def get_value(self):
         """
         Get the value, converted to the readable form
@@ -157,7 +149,8 @@ class ListControl(ListDeviceOption):
             if not value in self._values_list.inverse:
                 raise ValueError('Invalid value for ' + self.name + ': ' + value)
             return self._values_list.inverse[value]
-        return self._values_list[int(value)]
+        # No conversion is required
+        return value
 
     def set_value(self, value):
         """
@@ -167,22 +160,10 @@ class ListControl(ListDeviceOption):
             raise ValueError('Invalid value for ' + self.name + ': ' + value)
         if isinstance(self._values_list, bidict):
             self._fset(self._values_list[value])
-        else:
-            self._fset(str(self._values_list.index(value)))
+        else:# No conversion is required
+            self._fset(value)
 
-class BooleanDeviceOption(DeviceOption):
-    """
-    Device option, that accepts only two values:
-    true or false
-    """
-
-    def get_value(self):
-        return self._fget()
-
-    def set_value(self, value):
-        self._fset(value)
-
-class BooleanOption(BooleanDeviceOption):
+class BooleanControl(DeviceOption):
     """
     Device option, that accepts only two values:
     true or false, and does data conversion internally
@@ -265,7 +246,7 @@ class ValueDeviceOption(DeviceOption):
         """
         return self._channels
 
-class StateDeviceOption(DeviceOption):
+class StateControl(DeviceOption):
     """
     Device option, that can only be read, and represents
     certain state (string)
@@ -279,7 +260,7 @@ class StateDeviceOption(DeviceOption):
 
     def set_value(self, value):
         del value
-        raise NotImplementedError('set_value not valid for StateDeviceOption')
+        raise NotImplementedError('set_value not valid for StateControl')
 
 class ActionControl(DeviceOption):
     """
