@@ -29,7 +29,7 @@ from decimal import Decimal
 
 from pyxperiment.controller import VisaInstrument
 from pyxperiment.controller.device_options import (
-    ValueDeviceOption, ListDeviceOption, TimeoutControl
+    ValueDeviceOption, ListControl, TimeoutControl
 )
 
 class Keithley2182Nanovoltmeter(VisaInstrument):
@@ -93,7 +93,7 @@ class Keithley2182Nanovoltmeter(VisaInstrument):
                 return range_value
         raise ValueError('Unkwown range ' + value)
 
-    meas_range_ch1 = ListDeviceOption(
+    meas_range_ch1 = ListControl(
         'Range CH1, V',
         range_values,
         get_func=lambda instr: instr.get_range(1),
@@ -101,7 +101,7 @@ class Keithley2182Nanovoltmeter(VisaInstrument):
         #enabled=lambda instr: not instr.autorange.get_value(),
     )
 
-    meas_range_ch2 = ListDeviceOption(
+    meas_range_ch2 = ListControl(
         'Range CH2, V',
         range_values,
         get_func=lambda instr: instr.get_range(2),
@@ -122,7 +122,7 @@ class Keithley2182Nanovoltmeter(VisaInstrument):
     def get_channel(self):
         return self.query('SENS:CHAN?')
 
-    meas_channel = ListDeviceOption(
+    meas_channel = ListControl(
         'Active channel',
         channel_values,
         get_func=get_channel,
