@@ -30,7 +30,7 @@ from decimal import Decimal
 import wx
 from pyxperiment.controller import VisaInstrument
 from pyxperiment.controller.device_options import (
-    ValueDeviceOption, ListDeviceOption
+    ValueDeviceOption, ListControl
 )
 from pyxperiment.frames.device_config import (
     DeviceConfig, ControlField, ControlPanel, MultiControlPanel, option_to_control
@@ -87,7 +87,7 @@ class LakeShore370ResBridge(VisaInstrument):
         'Closed Loop (PID)', 'Zone', 'Open Loop', 'Off'
     ]
 
-    sample_control_mode = ListDeviceOption(
+    sample_control_mode = ListControl(
         'Heater mode', control_mode_values,
         get_func=lambda instr:
         instr.control_mode_values[int(instr.query('CMODE?'))-1],
@@ -121,7 +121,7 @@ class LakeShore370ResBridge(VisaInstrument):
         '1.00 mA', '3.16 mA', '10.0 mA', '31.6 mA', '100 mA'
         ]
 
-    sample_heater_range = ListDeviceOption(
+    sample_heater_range = ListControl(
         'Sample heater range', heater_range_values,
         get_func=lambda instr:
         instr.heater_range_values[int(instr.query('HTRRNG?'))],
