@@ -27,7 +27,7 @@
 
 from pyxperiment.controller import VisaInstrument
 from pyxperiment.controller.device_options import (
-    ListControl, StateDeviceOption, ActionControl
+    ListControl, StateControl, ActionControl
 )
 
 class SR5113Preamplifier(VisaInstrument):
@@ -152,7 +152,7 @@ class SR5113Preamplifier(VisaInstrument):
         )
     del _freq_vals
 
-    overload = StateDeviceOption(
+    overload = StateControl(
         'Overload',
         get_func=lambda instr: 'Overload ' if instr.query('ST') & 1 << 3 else 'Normal',
     )
