@@ -30,7 +30,9 @@ from decimal import Decimal
 
 from pyxperiment.controller import Instrument
 from pyxperiment.controller.validation import StaticRangeValidator
-from pyxperiment.controller.device_options import ValueDeviceOption, BooleanOption, ListDeviceOption
+from pyxperiment.controller.device_options import (
+    ListControl, ValueDeviceOption, BooleanControl
+)
 
 class ZtecZT410ADC(Instrument):
     """
@@ -322,13 +324,13 @@ class ZtecZT410ADC(Instrument):
         sweepable=False
     )
 
-    channel_1_enable = BooleanOption(
+    channel_1_enable = BooleanControl(
         'Enable channel 1',
         get_func=lambda instr: instr.query_ch(instr.ZT410_CMD_CHAN_STAT, instr.ZT410_INPUT_CH1),
         set_func=lambda instr, value: instr.write_ch(instr.ZT410_CMD_CHAN_STAT, instr.ZT410_INPUT_CH1, value)
     )
 
-    channel_2_enable = BooleanOption(
+    channel_2_enable = BooleanControl(
         'Enable channel 2',
         get_func=lambda instr: instr.query_ch(instr.ZT410_CMD_CHAN_STAT, instr.ZT410_INPUT_CH2),
         set_func=lambda instr, value: instr.write_ch(instr.ZT410_CMD_CHAN_STAT, instr.ZT410_INPUT_CH2, value)
@@ -365,22 +367,19 @@ class ZtecZT410ADC(Instrument):
         for i in range(0, 2)]
 
     ch_coup = [
-        ListDeviceOption(
-            'Coupling CH' + str(i+1), ['AC', 'DC'],
-            get_func=lambda instr, ch=i:
-            'DC' if instr.query_ch(instr.ZT410_CMD_VERT_COUP, ch) == '1' else 'AC',
-            set_func=lambda instr, value, ch=i:
-            instr.write_ch(instr.ZT410_CMD_VERT_COUP, ch, '1' if value == 'DC' else '0')
+        ListControl(
+            'Coupling CH' + str(i+1), dict(zip(['AC', 'DC'],map(str,range(2)))),
+            get_func=lambda instr, ch=i: instr.query_ch(instr.ZT410_CMD_VERT_COUP, ch),
+            set_func=lambda instr, val, ch=i: instr.write_ch(instr.ZT410_CMD_VERT_COUP, ch, val)
             )
         for i in range(0, 2)]
 
     ch_imp = [
-        ListDeviceOption(
-            'Impedance CH' + str(i+1) + ', Ohm', ['50.0', '1000000.0'],
-            get_func=lambda instr, ch=i:
-            instr.query_ch(instr.ZT410_CMD_VERT_IMP, ch),
-            set_func=lambda instr, value, ch=i:
-            instr.write_ch(instr.ZT410_CMD_VERT_IMP, ch, value)
+        ListControl(
+            'Impedance CH' + str(i+1),
+            dict(zip(['50 Ohm', '1 MOhm'],['50.0', '1000000.0'])),
+            get_func=lambda instr, ch=i: instr.query_ch(instr.ZT410_CMD_VERT_IMP, ch),
+            set_func=lambda instr, value, ch=i: instr.write_ch(instr.ZT410_CMD_VERT_IMP, ch, value)
             )
         for i in range(0, 2)]
         
\ No newline at end of file
