@@ -29,7 +29,7 @@ from decimal import Decimal
 from pyxperiment.core.utils import bidict
 from pyxperiment.controller.zurich_instrument import ZurichInstrument
 from pyxperiment.controller.device_options import (
-    ValueDeviceOption, BooleanOption, ListDeviceOption, TimeoutControl
+    ValueDeviceOption, BooleanControl, ListControl, TimeoutControl
 )
 
 class ZurichMFLI(ZurichInstrument):
@@ -73,7 +73,7 @@ class ZurichMFLI(ZurichInstrument):
         set_func=lambda instr, value: instr.set_double('/%s/SIGOUTS/0/AMPLITUDES/1', value),
     )
 
-    osc_enable = BooleanOption(
+    osc_enable = BooleanControl(
         'Oscillator enable',
         get_func=lambda instr: instr.get_int('/%s/SIGOUTS/0/ENABLES/1'),
         set_func=lambda instr, value: instr.set_int('/%s/SIGOUTS/0/ENABLES/1', value),
@@ -96,20 +96,20 @@ class ZurichMFLI(ZurichInstrument):
                 return range_value[0]
         raise ValueError('Unkwown range ' + value)
 
-    osc_range = ListDeviceOption(
+    osc_range = ListControl(
         'Oscillator range', osc_range_values,
         get_func=lambda instr: instr.get_osc_range(),
         set_func=lambda instr, value:
         instr.set_double('/%s/SIGOUTS/0/RANGE', instr.osc_range_values[value]),
     )
 
-    out_differential = BooleanOption(
+    out_differential = BooleanControl(
         'Differential output',
         get_func=lambda instr: instr.get_int('/%s/SIGOUTS/0/DIFF'),
         set_func=lambda instr, value: instr.set_int('/%s/SIGOUTS/0/DIFF', value),
     )
 
-    out_enable = BooleanOption(
+    out_enable = BooleanControl(
         'Output enable',
         get_func=lambda instr: instr.get_int('/%s/SIGOUTS/0/ON'),
         set_func=lambda instr, value: instr.set_int('/%s/SIGOUTS/0/ON', value),
@@ -133,7 +133,7 @@ class ZurichMFLI(ZurichInstrument):
         '48 dB/oct':'8'
     })
 
-    demod_order = ListDeviceOption(
+    demod_order = ListControl(
         'Slope order', demod_order_values,
         get_func=lambda instr:
         instr.demod_order_values.inverse[instr.get_int('/%s/DEMODS/0/ORDER')],
@@ -160,7 +160,7 @@ class ZurichMFLI(ZurichInstrument):
                 return range_value[0]
         raise ValueError('Unkwown range ' + value)
 
-    input_range = ListDeviceOption(
+    input_range = ListControl(
         'Input range', input_range_values,
         get_func=lambda instr: instr.get_input_range(),
         set_func=lambda instr, value:
@@ -265,7 +265,7 @@ class ZurichMFLI(ZurichInstrument):
         for i in range(0, 4)]
 
     pid_keep_value = [
-        BooleanOption(
+        BooleanControl(
             'PID' + str(i+1) + ' Keep I Value',
             get_func=lambda instr, num=i:
             instr.get_int('/%s/PIDS/' + str(num) + '/keepint'),
@@ -297,7 +297,7 @@ class ZurichMFLI(ZurichInstrument):
         for i in range(0, 4)]
 
     pid_enable = [
-        BooleanOption(
+        BooleanControl(
             'PID' + str(i+1) + ' Enable',
             get_func=lambda instr, num=i:
             instr.get_int('/%s/PIDS/' + str(num) + '/ENABLE'),
