@@ -140,9 +140,20 @@ class ExperimentSetupFrame(wx.Frame):
             CoreSettings.get_device_settings().get_children()
         ))
         drivers = self.res_manager.list_drivers()
+        drivers = {driver.driver_name() : driver for driver in drivers}
+        # Find the instruments without a valid name
+        bad_instruments = set(filter(lambda x: not x.driverName in drivers.keys(), saved_resources))
+        for instr in bad_instruments:
+            wx.MessageDialog(
+                self,
+                'The instrument driver: ' + instr.driverName + ' cannot be found. ' + 
+                'Please update the device library.',
+                'Invalid instrument driver',
+                wx.OK | wx.ICON_WARNING
+                ).ShowModal()
         saved_resources = [
-            (setting, next(x for x in drivers if x.driver_name() == setting.driverName))
-            for setting in saved_resources
+            (setting, drivers[setting.driverName])
+            for setting in saved_resources if not setting in bad_instruments
             ]
         readable_devices = list(filter(lambda x: x[1].is_readable(), saved_resources))
         writable_devices = list(filter(lambda x: x[1].is_writable(), saved_resources))
